@@ -4,8 +4,6 @@ magrittr::`%>%`
 
 null <- function(...) invisible()
 
-klass <- function(x) paste(class(x), collapse = "/")
-
 # Tools for finding srcrefs -----------------------------------------------
 
 find_first_srcref <- function(start) {
@@ -51,31 +49,18 @@ strrep <- function(x, times) {
   }, list(x = x, times = times), MoreArgs = list()), use.names = FALSE)
 }
 
+# Backport for R < 4.0
+deparse1 <- function(expr, ...) paste(deparse(expr, ...), collapse = "\n")
+
 can_entrace <- function(cnd) {
   !inherits(cnd, "Throwable")
 }
 
-remove_source <- function(x) {
-  if (is_closure(x)) {
-    body(x) <- remove_source(body(x))
-    x
-  } else if (is_call(x)) {
-    attr(x, "srcref") <- NULL
-    attr(x, "wholeSrcref") <- NULL
-    attr(x, "srcfile") <- NULL
-
-    x[] <- lapply(x, remove_source)
-    x
-  } else {
-    x
-  }
-}
-
 # Need to strip environment and source references to make lightweight
 # function suitable to send to another process
 transport_fun <- function(f) {
   environment(f) <- .GlobalEnv
-  f <- remove_source(f)
+  f <- zap_srcref(f)
   f
 }
 
@@ -126,3 +111,11 @@ first_upper <- function(x) {
   substr(x, 1, 1) <- toupper(substr(x, 1, 1))
   x
 }
+
+in_rcmd_check <- function() {
+  nzchar(Sys.getenv("_R_CHECK_PACKAGE_NAME_", ""))
+}
+
+map_chr <- function(.x, .f, ...) {
+  vapply(.x, .f, FUN.VALUE = character(1), ...)
+}
